@@ -189,7 +189,14 @@ def get_unlabeled_tfrecord_format(dict, img_size):
 	
 	dictionary_unlabeled = dict
 	IMAGE_SIZE = img_size
+
+## laters	
+def set_parameters(epochs, batch_size_base, GCS_PATH):
+	from kaggle_datasets import KaggleDatasets
+	GCS_DS_PATH = KaggleDatasets().get_gcs_path(GCS_PATH)
+	print(f'GCS_DS_PATH ->  {GCS_DS_PATH}')
 	
+	STEPS_PER_EPOCH = None
 
 if __name__ == "__main__":
 	pass
