@@ -92,7 +92,18 @@ def create_tfrecords_from_csv(data_dir, csv_path, outputfilename, IMAGE_SIZE = (
 	addrs = glob.glob(data_dir + '/*.jpg')
 	addrs.sort()
 	labels = list(df['Image'])
+	
+	labels_dict = {}
+    labels_unique = list(set(labels))
+    labels_unique.sort()
 
+    for i, class_ in enumerate(labels_unique):
+        labels_dict[class_] = i
+        
+    print(f"Encodings for the classes are -> {labels_dict}")
+    
+    labels = [labels_dict[i] for i in labels]
+	
 	c = list(zip(addrs, labels))
 	shuffle(c)
 
@@ -113,7 +124,18 @@ def create_split_tfrecords_from_csv(data_dir, csv, outfile1name, outfile2name, s
 	addrs = glob.glob(data_dir + '/*.jpg')
 	addrs.sort()
 	labels = list(df['Image'])
+	
+	labels_dict = {}
+    labels_unique = list(set(labels))
+    labels_unique.sort()
 
+    for i, class_ in enumerate(labels_unique):
+        labels_dict[class_] = i
+        
+    print(f"Encodings for the classes are -> {labels_dict}")
+    
+    labels = [labels_dict[i] for i in labels]
+	
 	c = list(zip(addrs, labels))
 	shuffle(c)
 	addrs, labels = zip(*c)
